"use client";
import Link from "next/link";
import { useEffect, useState } from "react";
import { account } from "@/lib/appwrite";
import { useTheme } from "@/components/ThemeProvider";

export default function Dashboard() {
    const [user, setUser] = useState(null);
    const { darkMode } = useTheme();

    useEffect(() => {
        const getUser = async () => {
            try {
                const response = await account.get();
                setUser(response);
            } catch (error) {
                window.location.href = "/login";
            }
        };
        getUser();
    }, []);

    const handleSignOut = async () => {
        try {
            await account.deleteSession("current");
            window.location.href = "/login";
        } catch (error) {
            alert("Error signing out: " + error.message);
        }
    };

    return (
        <div className={`flex flex-col items-center justify-center min-h-screen 
            ${darkMode ? 'bg-gray-800' : 'bg-gray-50'} // Softer dark background
            ${darkMode ? 'text-gray-100' : 'text-gray-800'} // Softer text color
            transition-colors duration-200 // Smooth transition
        `}>
            <h1 className="text-2xl font-bold mb-6">Welcome to Dashboard</h1>
            
            <Link href="/dashboard/crud">
                <button className={`
                    ${darkMode ? 'bg-blue-600 hover:bg-blue-700' : 'bg-blue-500 hover:bg-blue-600'} 
                    text-white px-4 py-2 rounded-lg shadow-md
                    transition-colors duration-200
                `}>
                    Go to CRUD Page
                </button>
            </Link>
            
            {user ? (
                <div className="mt-8 text-center">
                    <h1 className="text-xl font-semibold mb-4">
                        Welcome, {user.name || user.email || "User"}
                    </h1>
                    <button
                        className={`
                            ${darkMode ? 'bg-red-600 hover:bg-red-700' : 'bg-red-500 hover:bg-red-600'}
                            text-white px-4 py-2 rounded-lg shadow-md
                            transition-colors duration-200
                        `}
                        onClick={handleSignOut}
                    >
                        Sign Out
                    </button>
                </div>
            ) : (
                <h1 className="mt-8 text-lg">Loading...</h1>            
            )}
        </div>
    );
}